@@ -83,8 +83,7 @@ Map data manipulation
 """
 
 import numpy as np
-import exceptions
-import _healpy_pixel_lib as pixlib
+from . import _healpy_pixel_lib as pixlib
 from functools import wraps
 
 #: Special value used for masked pixels
@@ -166,20 +165,20 @@ def ma_to_array(m):
     >>> import healpy as hp
     >>> m = hp.ma(np.array([2., 2., 3, 4, 5, 0, 0, 0, 0, 0, 0, 0]))
     >>> m.mask = np.array([0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=np.bool)
-    >>> print m.data[1] # data is not affected by mask
+    >>> print(m.data[1]) # data is not affected by mask
     2.0
-    >>> print m[1] # shows that the value is masked
+    >>> print(m[1]) # shows that the value is masked
     --
-    >>> print ma_to_array(m)[1] # filled array, masked values replace by UNSEEN
+    >>> print(ma_to_array(m)[1]) # filled array, masked values replace by UNSEEN
     -1.6375e+30
     """
 
     try:
         return m.filled()
-    except exceptions.AttributeError:
+    except AttributeError:
         try:
             return tuple([mm.filled() for mm in m])
-        except exceptions.AttributeError:
+        except AttributeError:
             pass
     return m
 
@@ -509,7 +508,7 @@ def ang2vec(theta, phi):
     """
     check_theta_valid(theta)
     if np.any(theta < 0) or np.any(theta > np.pi):
-        raise exceptions.ValueError('THETA is out of range [0,pi]')
+        raise ValueError('THETA is out of range [0,pi]')
     sintheta = np.sin(theta)
     return np.array([sintheta*np.cos(phi),
                       sintheta*np.sin(phi),
@@ -564,7 +563,7 @@ def ring2nest(nside, ipix):
     >>> hp.ring2nest(16, 1504)
     1130
 
-    >>> hp.ring2nest(2, range(10))
+    >>> hp.ring2nest(2, np.arange(10))
     array([ 3,  7, 11, 15,  2,  1,  6,  5, 10,  9])
     
     >>> hp.ring2nest([1, 2, 4, 8], 11)
@@ -598,7 +597,7 @@ def nest2ring(nside, ipix):
     >>> hp.nest2ring(16, 1130)
     1504
 
-    >>> hp.nest2ring(2, range(10))
+    >>> hp.nest2ring(2, np.arange(10))
     array([13,  5,  4,  0, 15,  7,  6,  1, 17,  9])
     
     >>> hp.nest2ring([1, 2, 4, 8], 11)
@@ -650,7 +649,7 @@ def reorder(map_in, inp=None, out=None, r2n=None, n2r=None):
                  mask = False,
            fill_value = 999999)
     <BLANKLINE>
-    >>> m = [range(12), range(12), range(12)]
+    >>> m = [np.arange(12.), np.arange(12.), np.arange(12.)]
     >>> m[0][2] = hp.UNSEEN
     >>> m[1][2] = hp.UNSEEN
     >>> m[2][2] = hp.UNSEEN
@@ -697,7 +696,7 @@ def reorder(map_in, inp=None, out=None, r2n=None, n2r=None):
             mapout.append(m_in)
         elif inp == 'RING':
             m_out = np.zeros(npix,dtype=type(m_in[0]))
-            for ibunch in range(npix/bunchsize):
+            for ibunch in range(npix//bunchsize):
                 ipix_n = np.arange(ibunch*bunchsize,
                                     (ibunch+1)*bunchsize)
                 ipix_r = nest2ring(nside, ipix_n)
@@ -705,7 +704,7 @@ def reorder(map_in, inp=None, out=None, r2n=None, n2r=None):
             mapout.append(m_out)
         elif inp == 'NEST':
             m_out = np.zeros(npix,dtype=type(m_in[0]))
-            for ibunch in range(npix/bunchsize):
+            for ibunch in range(npix//bunchsize):
                 ipix_r = np.arange(ibunch*bunchsize,
                                     (ibunch+1)*bunchsize)
                 ipix_n = ring2nest(nside, ipix_r)
@@ -978,6 +977,10 @@ def get_interp_val(m,theta,phi,nest=False):
     >>> import healpy as hp
     >>> hp.get_interp_val(np.arange(12.), np.pi/2, 0)
     4.0
+    >>> hp.get_interp_val(np.arange(12.), np.pi/2, np.pi/2)
+    5.0
+    >>> hp.get_interp_val(np.arange(12.), np.pi/2, np.pi/2 + 2*np.pi)
+    5.0
     >>> hp.get_interp_val(np.arange(12.), np.linspace(0, np.pi, 10), 0)
     array([ 1.5       ,  1.5       ,  1.5       ,  2.20618428,  3.40206143,
             5.31546486,  7.94639458,  9.5       ,  9.5       ,  9.5       ])
@@ -1145,7 +1148,7 @@ def fit_dipole(m, nest=False, bad=UNSEEN, gal_cut=0):
         bunchsize = npix
     aa = np.zeros((4,4),dtype=np.float64)
     v = np.zeros(4,dtype=np.float64)
-    for ibunch in range(npix/bunchsize):
+    for ibunch in range(npix//bunchsize):
         ipix = np.arange(ibunch*bunchsize,
                           (ibunch+1)*bunchsize)
         ipix = ipix[(m.flat[ipix]!=bad) & (np.isfinite(m.flat[ipix]))]
@@ -1224,7 +1227,7 @@ def remove_dipole(m,nest=False,bad=UNSEEN,gal_cut=0,fitval=False,
     else:
         bunchsize = npix
     mono,dipole = fit_dipole(m,nest=nest,bad=bad,gal_cut=gal_cut)
-    for ibunch in range(npix/bunchsize):
+    for ibunch in range(npix//bunchsize):
         ipix = np.arange(ibunch*bunchsize,
                           (ibunch+1)*bunchsize)
         ipix = ipix[(m.flat[ipix]!=bad) & (np.isfinite(m.flat[ipix]))]
@@ -1237,10 +1240,9 @@ def remove_dipole(m,nest=False,bad=UNSEEN,gal_cut=0,fitval=False,
         import rotator as R
         lon,lat = R.vec2dir(dipole,lonlat=True)
         amp = np.sqrt((dipole**2).sum())
-        print 'monopole: %g  dipole: lon: %g, lat: %g, amp: %g'%(mono,
-                                                                 lon,
-                                                                 lat,
-                                                                 amp)
+        print(
+            'monopole: {0:g}  dipole: lon: {1:g}, lat: {2:g}, amp: {3:g}'
+            .format(mono, lon, lat, amp))
     if is_ma:
         m = ma(m)
     if fitval:
@@ -1280,7 +1282,7 @@ def fit_monopole(m,nest=False,bad=pixlib.UNSEEN,gal_cut=0):
     else:
         bunchsize=npix
     aa = v = 0.0
-    for ibunch in range(npix/bunchsize):
+    for ibunch in range(npix//bunchsize):
         ipix = np.arange(ibunch*bunchsize,
                           (ibunch+1)*bunchsize)
         ipix = ipix[(m.flat[ipix]!=bad) & (np.isfinite(m.flat[ipix]))]
@@ -1338,14 +1340,14 @@ def remove_monopole(m,nest=False,bad=pixlib.UNSEEN,gal_cut=0,fitval=False,
     else:
         bunchsize = npix
     mono = fit_monopole(m,nest=nest,bad=bad,gal_cut=gal_cut)
-    for ibunch in range(npix/bunchsize):
+    for ibunch in range(npix//bunchsize):
         ipix = np.arange(ibunch*bunchsize,
                           (ibunch+1)*bunchsize)
         ipix = ipix[(m.flat[ipix]!=bad) & (np.isfinite(m.flat[ipix]))]
         x,y,z = pix2vec(nside, ipix, nest)
         m.flat[ipix] -= mono
     if verbose:
-        print 'monopole: %g'%mono
+        print('monopole: {0:g}'.format(mono))
     if input_ma:
         m = ma(m)
     if fitval:
@@ -1379,14 +1381,14 @@ def get_map_size(m):
      --------
     >>> import healpy as hp
      >>> m = {0: 1, 1: 1, 2: 1, 'nside': 1}
-     >>> print hp.get_map_size(m)
+     >>> print(hp.get_map_size(m))
      12
 
      >>> m = {0: 1, 767: 1}
-     >>> print hp.get_map_size(m)
+     >>> print(hp.get_map_size(m))
      768
 
-     >>> print hp.get_map_size(np.zeros(12 * 8 ** 2))
+     >>> print(hp.get_map_size(np.zeros(12 * 8 ** 2)))
      768
     """
     if isinstance(m, dict):
@@ -1473,7 +1475,7 @@ def ud_grade(map_in,nside_out,pess=False,order_in='RING',order_out=None,
     order_in, order_out : str
       pixel ordering of input and output ('RING' or 'NESTED')
     power : float
-      if non-zero, multiply the result by (nside_in/nside_out)**power
+      if non-zero, divide the result by (nside_in/nside_out)**power
       Examples:
       power=-2 keeps the sum of the map invariant (useful for hitmaps),
       power=2 divides the mean by another factor of (nside_in/nside_out)**2
